@@ -1,6 +1,6 @@
 # Almost Free Text (AFT) Parser
 #
-# Copyright (C) 1996-2004 Todd A. Coram. All rights reserved.
+# Copyright (C) 1996-2005 Todd A. Coram. All rights reserved.
 #
 # This perl script parses aft documents and produces output formatted according
 # to an aft 'element' file.  See aft-refman.aft  for additional information.
@@ -20,9 +20,9 @@ use vars qw ($VERSION $version $outputfile $element_type $author $title
 
 $author = '';
 $title = '';
-$VERSION="v5.095";
+$VERSION="v5.096";
 $version=
-  "Almost Free Text $VERSION; Copyright 1996-2004 Todd Coram. All rights reserved.";
+  "Almost Free Text $VERSION; Copyright 1996-2005 Todd Coram. All rights reserved.";
 
 $element_type="bn-html";		# Default
 $outputfile='';			# Output file
@@ -269,7 +269,8 @@ sub output_notes {
     &output($AFT_OUTPUT::elem{'HorizontalLine'}."\n");
     my $count = 1;
     foreach my $note (@note) {
-	&do_string("=[(fNOTE$count)]=\n\\[[$count(REFfNOTE$count)]] - $note\n\\\\");
+	&do_string("=[(fNOTE$count)]=\n\\[[$count(REFfNOTE$count)]] - $note\n");
+	&output($AFT_OUTPUT::elem{'LineBreak'});
 	$count++;
     }
 }
@@ -362,7 +363,7 @@ sub process_f_h__file {
     LINE: while (<$fh>) {
 	$lcnt++;
 	chop;
-	$continued_line .= $1, next LINE if /(.*)\\$/; # collect continuations
+	$continued_line .= $1, next LINE if (/(.*)\\$/ and !$mode->{inVerbatim}); # collect continuations
 	&do_string($continued_line.$_, $fname, $lcnt); # process complete line
 	$continued_line = "";
     }
